==> global-0.0.8.tar.gz: lib/src/dialogs/GHeaderAndActionDialog.dart <==
import 'package:flutter/material.dart';
import 'package:global/global.dart';

abstract class GHeaderAndActionDialog extends StatefulWidget {
  const GHeaderAndActionDialog({super.key});
}

abstract class GHeaderAndActionDialogState<T extends GHeaderAndActionDialog>
    extends State<GHeaderAndActionDialog> {
  @override
  Widget build(BuildContext context) => Container(
        padding: const EdgeInsets.all(12),
        decoration:
            GUtils.getRoundBoxDecoration(radius: 10, borderWidth: 0),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Row(
              children: [
                Expanded(
                  child: Align(
                    alignment: Alignment.centerLeft,
                    child: GUtils.getText(
                      title: getHeaderText().toUpperCase(),
                      fontSize: 16.5,
                      fontWeight: FontWeight.w600,
                      color: Global.themeColor,
                    ),
                  ),
                ),
                GestureDetector(
                  onTap: () => Navigator.pop(context),
                  child: const Icon(
                    Icons.close_sharp,
                    size: 23,
                    color: Color(0xFF4D4D4D),
                  ),
                ),
              ],
            ),
            const SizedBox(height: 14),
            ConstrainedBox(
              constraints: const BoxConstraints(minHeight: 90, maxHeight: 500),
              child: contentBuilder(context),
            ),
            const SizedBox(height: 10),
            Row(children: _getActionRowChildren()),
          ],
        ),
      );

  String getHeaderText();

  Widget contentBuilder(BuildContext context);

  List<Map<String, Function>> getButtonsDetails() => [];

  List<Widget> _getActionRowChildren() {
    var buttonsDetailsList = getButtonsDetails();
    List<Widget> actionRowChildren = [];
    for (int i = 0; i < buttonsDetailsList.length; i++) {
      actionRowChildren.add(Expanded(
        child: GUtils.getActionElevatedButton(
          topBottomPadding: 8.5,
          fontSize: 13,
          title: buttonsDetailsList[i].entries.first.key.toUpperCase(),
          onPressed: () => buttonsDetailsList[i].entries.first.value(),
        ),
      ));
      if (i < buttonsDetailsList.length - 1) {
        actionRowChildren.add(const SizedBox(width: 10));
      }
    }
    return actionRowChildren;
  }
}

==> global-0.0.24.tar.gz: lib/src/dialogs/GHeaderAndActionDialog.dart <==
import 'package:flutter/material.dart';
import 'package:global/global.dart';

abstract class GHeaderAndActionDialog extends StatefulWidget {
  const GHeaderAndActionDialog({super.key});
}

abstract class GHeaderAndActionDialogState<T extends GHeaderAndActionDialog>
    extends State<GHeaderAndActionDialog> {
  @override
  Widget build(BuildContext context) => Container(
        padding: const EdgeInsets.all(12),
        decoration: GUtils.getRoundBoxDecoration(radius: 10, borderWidth: 0),
        child: Column(
          mainAxisSize: MainAxisSize.min,
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Row(
              children: [
                Expanded(
                  child: Align(
                    alignment: Alignment.centerLeft,
                    child: getHeader(),
                  ),
                ),
                GestureDetector(
                  onTap: () => Navigator.pop(context),
                  child: const Icon(
                    Icons.close_sharp,
                    size: 23,
                    color: Color(0xFF4D4D4D),
                  ),
                ),
              ],
            ),
            const SizedBox(height: 14),
            ConstrainedBox(
              constraints: const BoxConstraints(minHeight: 90, maxHeight: 500),
              child: contentBuilder(context),
            ),
            const SizedBox(height: 10),
            Row(children: _getButtonList()),
          ],
        ),
      );

  Widget getHeader();

  Widget contentBuilder(BuildContext context);

  int getButtonCount();

  Widget getButton(int index) => const SizedBox();

  List<Widget> _getButtonList() {
    List<Widget> buttonList = [];
    for (int i = 0; i < getButtonCount(); i++) {
      buttonList.add(Expanded(child: getButton(i)));
      if (i < getButtonCount() - 1) {
        buttonList.add(const SizedBox(width: 10));
      }
    }
    return buttonList;
  }
}
